'''
'''

from os import (
    environ as env
)
from pathlib import Path
import setuptools
import yaml


with open('./env.yml', 'r', encoding='utf-8') as vars_file:
    conf = yaml.safe_load(vars_file)

NAMESPACE = conf['NAMESPACE']
GIT_URL = env.get('CI_PROJECT_URL', 'http://localhost')

kwargs = {
    'name': f'{NAMESPACE.replace(".", "-")}',
    'version': f'{conf["VERSION"]}{env.get("BUILD_SUFIX", ".")}{env.get("CI_PIPELINE_IID", "0")}',
    'author': conf['AUTHOR'],
    'author_email': conf['EMAIL'],
    'description': conf['DESCR'],
    'url': conf['NOTION'],
    'keywords': conf['KEYWORDS'],
    'project_urls': {
        'Source code': GIT_URL
    },
    'package_dir': {"": "src"},
    'packages': [
        NAMESPACE
    ],
    'namespace_modules': [
        NAMESPACE
    ],
    'python_requires': conf['PYTHON_REQ'],
    'classifiers': conf['CLASSIFIERS'],
    'install_requires': conf['REQUIREMENTS']
}

if Path('README.md').is_file():

    with open('README.md', 'r', encoding='utf-8') as md:
        long_description = md.read()

    if len(long_description) > 0:
        kwargs['long_description_content_type'] = 'text/markdown'
        kwargs['long_description'] = long_description


def add_urls(key: str, alias: str = None) -> None:
    '''
    Check env.yml & add value to project_urls.
    '''
    global kwargs
    name = alias if alias else key.capitalize()
    if key in conf and conf[key] != '':
        kwargs['project_urls'][name] = conf[key]


add_urls('DONATE')
add_urls('SKYANT', 'SkyANT')
add_urls('MAF', 'Micro-Application Framework')

setuptools.setup(**kwargs)
